Learn R Programming

shinyrecipes (version 0.1.0)

recipesGadget: Recipes Gadget

Description

Gadget to use the data preprocessing 'recipes' package interactively.

Usage

recipesGadget(.df, bake_list = NULL)

Arguments

.df

data frame, data table or tibble on which the preprocessing steps will be trained.

bake_list

A named list where each element is a data.frame, data.table or tibble on which the selected preprocessing steps can be applied.

Value

Returns a list containing the trained recipe as well as all the data to which the recipe has been applied within the gadget.

Details

Find more information in the [shinyrecipes](https://albertoalmuinha.github.io/shinyrecipes/) web page.

Examples

Run this code
# NOT RUN {
{if(interactive()){
recipesGadget(.df = mtcars, bake_list = list('mtcars1' = mtcars1))
}
}
# }

Run the code above in your browser using DataLab