powered by
Gadget to use the data preprocessing 'recipes' package interactively.
recipesGadget(.df, bake_list = NULL)
data frame, data table or tibble on which the preprocessing steps will be trained.
A named list where each element is a data.frame, data.table or tibble on which the selected preprocessing steps can be applied.
Returns a list containing the trained recipe as well as all the data to which the recipe has been applied within the gadget.
Find more information in the [shinyrecipes](https://albertoalmuinha.github.io/shinyrecipes/) web page.
# NOT RUN { {if(interactive()){ recipesGadget(.df = mtcars, bake_list = list('mtcars1' = mtcars1)) } } # }
Run the code above in your browser using DataLab